;
; eepromtbl.asm  - A collection of data definition to be stored in eeprom
;
;  Copyright (C) 2011 Hazimin Fauzi <hazimin@gmail.com>
;  Copyright (C) 2011 Roman Black   <http://www.romanblack.com>
;
; ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
; Permission is hereby granted, free of charge, to any person obtaining a 
; copy of this software and associated documentation files (the “Software”),
; to deal in the Software without restriction, including without limitation 
; the rights to use, copy, modify, merge, publish, distribute, sublicense,
; and/or sell copies of the Software, and to permit persons to whom the 
; Software is furnished to do so, subject to the following conditions:
;
; The above copyright notice and this permission notice shall be 
; included in all copies or substantial portions of the Software.
; ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


	list    p=16f628a
	include "p16f628a.inc"
	org 0x2100	; change this to eeprom address of your processor


	;-------------------------------------------------
	; HIGH POWER TABLE
	;-------------------------------------------------
	; here are the 36 value pairs for the high power table.
	;
	; CURRENT INFO.
	; hardware requires that we send the entire 8 bits to the motor
	; at one time, to keep pwm fast.

	; ----xxxx,  where xxxx is the coils on/off phasing (done)
	; xxxx----,  where xxxx is the current settings for the A and B phases;
	; xx------,  where xx is current for A phase
	; --xx----,  where xx is current for B phase

	; hardware currents for 6th stepping have 4 possible values;
	; 00  =  0% current
	; 01  =  25% current
	; 10  =  55% current
	; 11  =  100% current
	;
	;-------------------------------------------------
	; PWM INFO.
	; hardware gives us 6th steps, or 1200 steps/rev.
	; to get 3600 steps/rev we need TWO more
	; "tween" steps between every proper hardware 6th step.

	; to do this we set 2 currents, current1 and current2.
	; then we do FAST pwm, with 2 time units at current2,
	; and 1 time unit at current1.
	; this gives a current which is between the two currents,
	; proportionally closer to current2. (2/3 obviously)
	; this gives the ability to get 2 evenly spaced "tween" currents
	; between our hardware 6th step currents, and go from 1200 to 3600.

	; the next 36 value pairs set the 2 currents desired, then
	; loaded to a fast-pwm loop (same loop used for all currents)
	; which modulates between the 2 currents and gives final
	; output current.
	;-------------------------------------------------
	; High Power Table				current: current2 : current1
	de b'11000000',b'11000000' ; 00: (6th step),	current: 100,000 : 100,000 
	de b'11000000',b'11010000' ; 01: (tween step),	current: 100,000 : 100,025
	de b'11010000',b'11000000' ; 02: (tween step),	current: 100,025 : 100,000
	de b'11010000',b'11010000' ; 03: (6th step),	current; 100,025 : 100,025
	de b'11010000',b'11100000' ; 04: (tween step),	current: 100,025 : 100,055
	de b'11100000',b'11010000' ; 05: (tween step),	current: 100,055 : 100,025
	de b'11100000',b'11100000' ; 06: (6th step),	current; 100,055 : 100,055
	de b'11100000',b'11110000' ; 07: (tween step),	current: 100,055 : 100,100
	de b'11110000',b'11100000' ; 08: (tween step),	current: 100,100 : 100,055
	de b'11110000',b'11110000' ; 09: (6th step),	current; 100,100 : 100,100
	de b'11110000',b'10110000' ; 10: (tween step),	current: 100,100 : 055,100
	de b'10110000',b'11110000' ; 11: (tween step),	current: 055,100 : 100,100
	de b'10110000',b'10110000' ; 12: (6th step),	current; 055,100 : 055,100
	de b'10110000',b'01110000' ; 13: (tween step),	current; 055,100 : 025,100
	de b'01110000',b'10110000' ; 14: (tween step),	current; 025,100 : 055,100
	de b'01110000',b'01110000' ; 15: (6th step),	current; 025,100 : 025,100
	de b'01110000',b'00110000' ; 16: (tween step),	current; 025,100 : 000,100
	de b'00110000',b'01110000' ; 17: (tween step),	current; 000,100 : 025,100
	de b'00110000',b'00110000' ; 18: (6th step),	current; 000,100 : 000,100
	de b'00110000',b'01110000' ; 19: (tween step),	current; 000,100 : 025,100
	de b'01110000',b'00110000' ; 20: (tween step),	current; 025,100 : 000,100
	de b'01110000',b'01110000' ; 21: (6th step),	current; 025,100 : 025,100
	de b'01110000',b'10110000' ; 22: (tween step),	current; 025,100 : 055,100
	de b'10110000',b'01110000' ; 23: (tween step),	current; 055,100 : 025,100
	de b'10110000',b'10110000' ; 24: (6th step),	current; 055,100 : 055,100
	de b'10110000',b'11110000' ; 25: (tween step),	current; 055,100 : 100,100
	de b'11110000',b'10110000' ; 26: (tween step),	current; 100,100 : 055,100
	de b'11110000',b'11110000' ; 27: (6th step),	current; 100,100 : 100,100
	de b'11110000',b'11100000' ; 28: (tween step),	current; 100,100 : 100,055
	de b'11100000',b'11110000' ; 29: (tween step),	current; 100,055 : 100,100
	de b'11100000',b'11100000' ; 30: (6th step),	current; 100,055 : 100,055
	de b'11100000',b'11010000' ; 31: (tween step),	current; 100,055 : 100,025
	de b'11010000',b'11100000' ; 32: (tween step),	current; 100,025 : 100,055
	de b'11010000',b'11010000' ; 33: (6th step),	current; 100,025 : 100,025
	de b'11010000',b'11000000' ; 34: (tween step),	current; 100,025 : 100,000
	de b'11000000',b'11010000' ; 35: (tween step),	current; 100,000 : 100,025  



	;-------------------------------------------------
	; LOW POWER TABLE
	;-------------------------------------------------
	; as low power mode is for wait periods we don't need to
	; maintain the full step precision and can wait on the
	; half-step (400 steps/rev). This means much easier code tables.
	; The nature of the board electronics is not really suited
	; for LOW power microstepping, but it could be programmed here
	; if needed.
	;
	; NOTE!! uses my hi-torque half stepping, not normal half step.
	;
	; doing half stepping with the 55,25 current values gives;
	; 55+25 = 80
	; max current 100+100 = 200
	; typical (high) current 100+50 = 150
	; so low power is about 1/2 the current of high power mode,
	; giving about 1/4 the motor heating and half the driver heating.

	; for now it uses only half-steps or 8 separate current modes.
	; we only have to use 4 actual current modes as
	; the table is doubled like the table_highpower is.
	;
	; NOTE!! This table is truncated to single value due to out of space in EEPROM
	; Expand to value pairs if you want to use full size table.
	;-------------------------------------------------      
	; current 	: current1 = current2
	de b'10010000'	; 0-8: current: 55.25
	de b'10010000'
	de b'10010000'
	de b'10010000'
	de b'10010000'
	de b'10010000'
	de b'10010000'
	de b'10010000'
	de b'10010000'
	de b'01100000'	; 9-17: current 25.55
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'01100000'	; 18-26: current 25.55
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'01100000'
	de b'10010000'	; 19-26: current 55.25
	de b'10010000'
	de b'10010000'
	de b'10010000'
	de b'10010000'
	de b'10010000'
	de b'10010000'
	de b'10010000'
	de b'10010000'

	;-------------------------------------------------
	; STEPPING TABLE
	;-------------------------------------------------
	; This table store stepping value for various mode
	; Mode 00 : 200 steps (72/18),4 valid step: 9,27,45,63
	; Mode 01 : 400 steps (72/9),8 valid step: 4,13,22,31,40,49,58,67
	; Mode 10 : 1200 steps (72/3), valid step is mod 3 (0,3,6,9 etc)
	; Mode 11 : 3600 steps (72/1), step increment by 1
	;-------------------------------------------------
	; step min, step max, step increment 
	de d'9',d'63',d'18'
	de d'4',d'67',d'9'
	de d'0',d'69',d'3'
	de d'0',d'71',d'1'
	end
